# Offline human review

## 1. Critical

## 2. Important

## 3. Minor
- [1] Group 1:
    - In section "Building a Sequential Workflow: FAQ Generation Pipeline", instead of having just the code output saying that it took 22 seconds to run the sequential workflow, it would be better to have an example of the sequential workflow output as well.
- [1] Group 2:
    - In section "Introducing Dynamic Behavior: Routing and Conditional Logic", mention that, with routing, it's then possible to route the models as well for specific tasks, as some models are better at specific tasks than others. Say that it will be covered in later in the course.
- [1] Group 3:
    - Edit the Mermaid diagram of the routing section so that the "Classify Intent" node is actually called "Router" node.
- [1] Group 4:
    - Expand a bit the code in the "def process_user_query(user_query)" function in the "Orchestrator-Worker Pattern: Dynamic Task Decomposition" section so that it shows more of how its "step 2" is done (where the tasks are dispatched)
- [1] Group 5:
    - The "Orchestrator-Worker Pattern: Dynamic Task Decomposition" section should also show the code of the synthetizer and explain it.
- [1] Group 6:
    - Don't use the word "embracing" and its derivatives, it's AI slop.
- [1] Group 7:
    - Don't use the "—" character, it's AI slop.
- [1] Group 8:
    - Don't use the word "crucial" and its derivatives, it's AI slop.

## ! Clashing

## Legend

A group is formatted as follows:
"[<frequency_number>] Group <group_number>:
    - <review>
    - <review>
    - ...
"